SimulatedAnnealingParameters

Struct SimulatedAnnealingParameters 

pub struct SimulatedAnnealingParameters<T, N>
where T: Clone, N: NeighborhoodOperator<T>,
{ pub neighborhood: N, pub initial_temperature: f64, pub minimum_temperature: f64, pub cooling_rate: f64, pub termination_criteria: TerminationCriteria, pub random_seed: Option<u64>, /* private fields */ }

Fields

neighborhood: Ninitial_temperature: f64minimum_temperature: f64cooling_rate: f64termination_criteria: TerminationCriteriarandom_seed: Option<u64>

Implementations

Source

impl<T, N> SimulatedAnnealingParameters<T, N>
where T: Clone, N: NeighborhoodOperator<T>,

pub fn new( neighborhood: N, initial_temperature: f64, cooling_rate: f64, termination_criteria: TerminationCriteria, ) -> Self

Examples found in repository?
examples/experiment_parallel_vs_sequential.rs (lines 58-63)
35fn run_experiment(parallel: bool, runs: usize) -> Result<(Duration, ExperimentReport), String> {
36    let problem = build_problem();
37
38    let hill_climbing_case = HillClimbingParameters::new(
39        BitFlipNeighborhood::new(),
40        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
41    )
42    .with_seed(111);
43
44    // Keep GA internally sequential to focus the comparison on experiment-level parallelism.
45    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
46            80,
47            0.90,
48            0.06,
49            SinglePointCrossover::new(),
50            BitFlipMutation::new(),
51            BinaryTournamentSelection::new(),
52            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
53        )
54        .with_elite_size(1)
55        .with_seed(222)
56        .sequential();
57
58    let simulated_annealing_case = SimulatedAnnealingParameters::new(
59        BitFlipNeighborhood::new(),
60        45.0,
61        0.985,
62        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
63    )
64    .with_seed(333);
65
66    let pso_case = PSOParameters::new(
67        50,
68        0.72,
69        1.49,
70        1.49,
71        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
72    )
73    .with_velocity_clamp(4.0)
74    .with_seed(444);
75
76    let experiment = Experiment::new(problem)
77        .with_runs(runs)
78        .add_case(hill_climbing_case)
79        .add_case(genetic_algorithm_case)
80        .add_case(simulated_annealing_case)
81        .add_case(pso_case);
82
83    measure_result(|| {
84        if parallel {
85            experiment.with_parallel().execute()
86        } else {
87            experiment.sequential().execute()
88        }
89    })
90}
More examples
Hide additional examples
examples/mono_objective_experiment.rs (lines 51-56)
13fn main() {
14    let problem = KnapsackBuilder::new()
15        .with_capacity(150.0)
16        .add_item(1.0, 2.0)
17        .add_item(1.0, 2.0)
18        .add_item(2.0, 6.0)
19        .add_item(2.0, 6.5)
20        .add_item(3.0, 7.0)
21        .add_item(10.0, 20.0)
22        .add_item(20.0, 30.0)
23        .add_item(30.0, 60.0)
24        .add_item(35.0, 65.0)
25        .add_item(45.0, 100.0)
26        .add_item(55.0, 120.0)
27        .add_item(75.0, 211.0)
28        .add_item(75.0, 211.0)
29        .add_item(80.0, 160.0)
30        .add_item(90.0, 301.0)
31        .add_item(150.0, 301.0)
32        .build();
33
34    let hill_climbing_case = HillClimbingParameters::new(
35            BitFlipNeighborhood::new(),
36            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
37        );
38
39    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
40            80,
41            0.90,
42            0.06,
43            SinglePointCrossover::new(),
44            BitFlipMutation::new(),
45            BinaryTournamentSelection::new(),
46            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
47        )
48        .with_elite_size(1)
49        .with_threads(4);
50
51    let simulated_annealing_case = SimulatedAnnealingParameters::new(
52        BitFlipNeighborhood::new(),
53        45.0,
54        0.985,
55        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
56    )
57    .with_seed(777);
58
59    let pso_case = PSOParameters::new(
60        50,
61        0.72,
62        1.49,
63        1.49,
64        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
65    )
66    .with_velocity_clamp(4.0)
67    .with_seed(999);
68
69    let report = Experiment::new(problem)
70        .with_runs(24)
71        .add_case(hill_climbing_case)
72        .add_case(genetic_algorithm_case)
73        .add_case(simulated_annealing_case)
74        .add_case(pso_case)
75        .execute();
76
77    match report {
78        Ok(report) => println!("{}", report.to_text_table()),
79        Err(error) => eprintln!("Experiment execution failed: {}", error),
80    }
81}
pub fn with_minimum_temperature(self, minimum_temperature: f64) -> Self

pub fn with_seed(self, seed: u64) -> Self

Examples found in repository?
examples/experiment_parallel_vs_sequential.rs (line 64)
35fn run_experiment(parallel: bool, runs: usize) -> Result<(Duration, ExperimentReport), String> {
36    let problem = build_problem();
37
38    let hill_climbing_case = HillClimbingParameters::new(
39        BitFlipNeighborhood::new(),
40        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
41    )
42    .with_seed(111);
43
44    // Keep GA internally sequential to focus the comparison on experiment-level parallelism.
45    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
46            80,
47            0.90,
48            0.06,
49            SinglePointCrossover::new(),
50            BitFlipMutation::new(),
51            BinaryTournamentSelection::new(),
52            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
53        )
54        .with_elite_size(1)
55        .with_seed(222)
56        .sequential();
57
58    let simulated_annealing_case = SimulatedAnnealingParameters::new(
59        BitFlipNeighborhood::new(),
60        45.0,
61        0.985,
62        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
63    )
64    .with_seed(333);
65
66    let pso_case = PSOParameters::new(
67        50,
68        0.72,
69        1.49,
70        1.49,
71        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
72    )
73    .with_velocity_clamp(4.0)
74    .with_seed(444);
75
76    let experiment = Experiment::new(problem)
77        .with_runs(runs)
78        .add_case(hill_climbing_case)
79        .add_case(genetic_algorithm_case)
80        .add_case(simulated_annealing_case)
81        .add_case(pso_case);
82
83    measure_result(|| {
84        if parallel {
85            experiment.with_parallel().execute()
86        } else {
87            experiment.sequential().execute()
88        }
89    })
90}
More examples
Hide additional examples
examples/mono_objective_experiment.rs (line 57)
13fn main() {
14    let problem = KnapsackBuilder::new()
15        .with_capacity(150.0)
16        .add_item(1.0, 2.0)
17        .add_item(1.0, 2.0)
18        .add_item(2.0, 6.0)
19        .add_item(2.0, 6.5)
20        .add_item(3.0, 7.0)
21        .add_item(10.0, 20.0)
22        .add_item(20.0, 30.0)
23        .add_item(30.0, 60.0)
24        .add_item(35.0, 65.0)
25        .add_item(45.0, 100.0)
26        .add_item(55.0, 120.0)
27        .add_item(75.0, 211.0)
28        .add_item(75.0, 211.0)
29        .add_item(80.0, 160.0)
30        .add_item(90.0, 301.0)
31        .add_item(150.0, 301.0)
32        .build();
33
34    let hill_climbing_case = HillClimbingParameters::new(
35            BitFlipNeighborhood::new(),
36            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
37        );
38
39    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
40            80,
41            0.90,
42            0.06,
43            SinglePointCrossover::new(),
44            BitFlipMutation::new(),
45            BinaryTournamentSelection::new(),
46            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
47        )
48        .with_elite_size(1)
49        .with_threads(4);
50
51    let simulated_annealing_case = SimulatedAnnealingParameters::new(
52        BitFlipNeighborhood::new(),
53        45.0,
54        0.985,
55        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
56    )
57    .with_seed(777);
58
59    let pso_case = PSOParameters::new(
60        50,
61        0.72,
62        1.49,
63        1.49,
64        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
65    )
66    .with_velocity_clamp(4.0)
67    .with_seed(999);
68
69    let report = Experiment::new(problem)
70        .with_runs(24)
71        .add_case(hill_climbing_case)
72        .add_case(genetic_algorithm_case)
73        .add_case(simulated_annealing_case)
74        .add_case(pso_case)
75        .execute();
76
77    match report {
78        Ok(report) => println!("{}", report.to_text_table()),
79        Err(error) => eprintln!("Experiment execution failed: {}", error),
80    }
81}