SimulatedAnnealingParameters

Struct SimulatedAnnealingParameters 

pub struct SimulatedAnnealingParameters<T, M>
where T: Clone, M: MutationOperator<T>,
{ pub mutation_operator: M, pub mutation_probability: f64, pub initial_temperature: f64, pub minimum_temperature: f64, pub cooling_rate: f64, pub termination_criteria: TerminationCriteria, pub random_seed: Option<u64>, /* private fields */ }

Fields

mutation_operator: Mmutation_probability: f64initial_temperature: f64minimum_temperature: f64cooling_rate: f64termination_criteria: TerminationCriteriarandom_seed: Option<u64>

Implementations

Source

impl<T, M> SimulatedAnnealingParameters<T, M>
where T: Clone, M: MutationOperator<T>,

pub fn new( mutation_operator: M, mutation_probability: f64, initial_temperature: f64, cooling_rate: f64, termination_criteria: TerminationCriteria, ) -> Self

Examples found in repository?
examples/experiment_parallel_vs_sequential.rs (lines 59-65)
35fn run_experiment(parallel: bool, runs: usize) -> Result<(Duration, ExperimentReport), String> {
36    let problem = build_problem();
37
38    let hill_climbing_case = HillClimbingParameters::new(
39        BitFlipMutation::new(),
40        0.12,
41        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
42    )
43    .with_seed(111);
44
45    // Keep GA internally sequential to focus the comparison on experiment-level parallelism.
46    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
47            80,
48            0.90,
49            0.06,
50            SinglePointCrossover::new(),
51            BitFlipMutation::new(),
52            BinaryTournamentSelection::new(),
53            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
54        )
55        .with_elite_size(1)
56        .with_seed(222)
57        .sequential();
58
59    let simulated_annealing_case = SimulatedAnnealingParameters::new(
60        BitFlipMutation::new(),
61        0.10,
62        45.0,
63        0.985,
64        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
65    )
66    .with_seed(333);
67
68    let pso_case = PSOParameters::new(
69        50,
70        0.72,
71        1.49,
72        1.49,
73        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
74    )
75    .with_velocity_clamp(4.0)
76    .with_seed(444);
77
78    let experiment = Experiment::new(problem)
79        .with_runs(runs)
80        .add_case(hill_climbing_case)
81        .add_case(genetic_algorithm_case)
82        .add_case(simulated_annealing_case)
83        .add_case(pso_case);
84
85    measure_result(|| {
86        if parallel {
87            experiment.with_parallel().execute()
88        } else {
89            experiment.sequential().execute()
90        }
91    })
92}
More examples
Hide additional examples
examples/mono_objective_experiment.rs (lines 52-58)
13fn main() {
14    let problem = KnapsackBuilder::new()
15        .with_capacity(150.0)
16        .add_item(1.0, 2.0)
17        .add_item(1.0, 2.0)
18        .add_item(2.0, 6.0)
19        .add_item(2.0, 6.5)
20        .add_item(3.0, 7.0)
21        .add_item(10.0, 20.0)
22        .add_item(20.0, 30.0)
23        .add_item(30.0, 60.0)
24        .add_item(35.0, 65.0)
25        .add_item(45.0, 100.0)
26        .add_item(55.0, 120.0)
27        .add_item(75.0, 211.0)
28        .add_item(75.0, 211.0)
29        .add_item(80.0, 160.0)
30        .add_item(90.0, 301.0)
31        .add_item(150.0, 301.0)
32        .build();
33
34    let hill_climbing_case = HillClimbingParameters::new(
35            BitFlipMutation::new(),
36            0.12,
37            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
38        );
39
40    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
41            80,
42            0.90,
43            0.06,
44            SinglePointCrossover::new(),
45            BitFlipMutation::new(),
46            BinaryTournamentSelection::new(),
47            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
48        )
49        .with_elite_size(1)
50        .with_threads(4);
51
52    let simulated_annealing_case = SimulatedAnnealingParameters::new(
53        BitFlipMutation::new(),
54        0.10,
55        45.0,
56        0.985,
57        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
58    )
59    .with_seed(777);
60
61    let pso_case = PSOParameters::new(
62        50,
63        0.72,
64        1.49,
65        1.49,
66        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
67    )
68    .with_velocity_clamp(4.0)
69    .with_seed(999);
70
71    let report = Experiment::new(problem)
72        .with_runs(24)
73        .add_case(hill_climbing_case)
74        .add_case(genetic_algorithm_case)
75        .add_case(simulated_annealing_case)
76        .add_case(pso_case)
77        .execute();
78
79    match report {
80        Ok(report) => println!("{}", report.to_text_table()),
81        Err(error) => eprintln!("Experiment execution failed: {}", error),
82    }
83}
pub fn with_minimum_temperature(self, minimum_temperature: f64) -> Self

pub fn with_seed(self, seed: u64) -> Self

Examples found in repository?
examples/experiment_parallel_vs_sequential.rs (line 66)
35fn run_experiment(parallel: bool, runs: usize) -> Result<(Duration, ExperimentReport), String> {
36    let problem = build_problem();
37
38    let hill_climbing_case = HillClimbingParameters::new(
39        BitFlipMutation::new(),
40        0.12,
41        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
42    )
43    .with_seed(111);
44
45    // Keep GA internally sequential to focus the comparison on experiment-level parallelism.
46    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
47            80,
48            0.90,
49            0.06,
50            SinglePointCrossover::new(),
51            BitFlipMutation::new(),
52            BinaryTournamentSelection::new(),
53            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
54        )
55        .with_elite_size(1)
56        .with_seed(222)
57        .sequential();
58
59    let simulated_annealing_case = SimulatedAnnealingParameters::new(
60        BitFlipMutation::new(),
61        0.10,
62        45.0,
63        0.985,
64        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
65    )
66    .with_seed(333);
67
68    let pso_case = PSOParameters::new(
69        50,
70        0.72,
71        1.49,
72        1.49,
73        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
74    )
75    .with_velocity_clamp(4.0)
76    .with_seed(444);
77
78    let experiment = Experiment::new(problem)
79        .with_runs(runs)
80        .add_case(hill_climbing_case)
81        .add_case(genetic_algorithm_case)
82        .add_case(simulated_annealing_case)
83        .add_case(pso_case);
84
85    measure_result(|| {
86        if parallel {
87            experiment.with_parallel().execute()
88        } else {
89            experiment.sequential().execute()
90        }
91    })
92}
More examples
Hide additional examples
examples/mono_objective_experiment.rs (line 59)
13fn main() {
14    let problem = KnapsackBuilder::new()
15        .with_capacity(150.0)
16        .add_item(1.0, 2.0)
17        .add_item(1.0, 2.0)
18        .add_item(2.0, 6.0)
19        .add_item(2.0, 6.5)
20        .add_item(3.0, 7.0)
21        .add_item(10.0, 20.0)
22        .add_item(20.0, 30.0)
23        .add_item(30.0, 60.0)
24        .add_item(35.0, 65.0)
25        .add_item(45.0, 100.0)
26        .add_item(55.0, 120.0)
27        .add_item(75.0, 211.0)
28        .add_item(75.0, 211.0)
29        .add_item(80.0, 160.0)
30        .add_item(90.0, 301.0)
31        .add_item(150.0, 301.0)
32        .build();
33
34    let hill_climbing_case = HillClimbingParameters::new(
35            BitFlipMutation::new(),
36            0.12,
37            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(180)]),
38        );
39
40    let genetic_algorithm_case = GeneticAlgorithmParameters::new(
41            80,
42            0.90,
43            0.06,
44            SinglePointCrossover::new(),
45            BitFlipMutation::new(),
46            BinaryTournamentSelection::new(),
47            TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(60)]),
48        )
49        .with_elite_size(1)
50        .with_threads(4);
51
52    let simulated_annealing_case = SimulatedAnnealingParameters::new(
53        BitFlipMutation::new(),
54        0.10,
55        45.0,
56        0.985,
57        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(220)]),
58    )
59    .with_seed(777);
60
61    let pso_case = PSOParameters::new(
62        50,
63        0.72,
64        1.49,
65        1.49,
66        TerminationCriteria::new(vec![TerminationCriterion::MaxIterations(120)]),
67    )
68    .with_velocity_clamp(4.0)
69    .with_seed(999);
70
71    let report = Experiment::new(problem)
72        .with_runs(24)
73        .add_case(hill_climbing_case)
74        .add_case(genetic_algorithm_case)
75        .add_case(simulated_annealing_case)
76        .add_case(pso_case)
77        .execute();
78
79    match report {
80        Ok(report) => println!("{}", report.to_text_table()),
81        Err(error) => eprintln!("Experiment execution failed: {}", error),
82    }
83}